@@ -80,60 +80,5 @@ pub fn format_str<S: AsRef<str>>(
     }
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
-pub struct IndentError {
-    msg: String,
-}
-
-impl Error for IndentError {
-    fn new<S: AsRef<str>>(msg: S) -> Self {
-        IndentError {
-            msg: msg.as_ref().to_string(),
-        }
-    }
-
-    fn from<E: Error>(err: &E) -> Self {
-        IndentError {
-            msg: err.to_string(),
-        }
-    }
-
-    fn to_string(&self) -> String {
-        self.msg.clone()
-    }
-}
-
-#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
-pub struct FormatError {
-    msg: String,
-    type_: FormatType,
-}
-
-impl FormatError {
-    pub fn with_type<S: AsRef<str>>(msg: S, type_: &FormatType) -> Self {
-        FormatError {
-            msg: msg.as_ref().to_string(),
-            type_: type_.clone(),
-        }
-    }
-}
-
-impl Error for FormatError {
-    fn new<S: AsRef<str>>(msg: S) -> Self {
-        FormatError {
-            msg: msg.as_ref().to_string(),
-            type_: FormatType::new(),
-        }
-    }
-
-    fn from<E: Error>(err: &E) -> Self {
-        FormatError {
-            msg: err.to_string(),
-            type_: FormatType::new(),
-        }
-    }
-
-    fn to_string(&self) -> String {
-        self.msg.clone()
-    }
-}
+pub type IndentError = Error;
+pub type FormatError = Error;
